AutoConsumer

Struct AutoConsumer 

pub struct AutoConsumer { /* private fields */ }
Automatic consumer that runs in a background thread.

This provides a handle to a consumer running automatic event processing in a separate thread. It supports graceful shutdown and cleanup operations.

Implementations

Source

impl AutoConsumer

pub fn shutdown(&self)

Signal the consumer to shutdown

pub fn join(&mut self)

Wait for the consumer thread to finish

pub fn shutdown_and_join(&mut self)

Shutdown and wait for the consumer thread to finish

pub fn is_running(&self) -> bool

Check if the consumer thread is still running