MmapConsumer

Struct MmapConsumer 

pub struct MmapConsumer<E> { /* private fields */ }
Consumer for the mmap transport.

Implementations

Source

impl<E> MmapConsumer<E>
where E: Copy + Default,

pub fn attach( layout: MmapTransportLayout, buffer_size: usize, consumer_id: &str, ) -> MultiProcessResult<Self>

Attach a consumer to an existing mmap transport.

pub fn signal_readiness(&self)

Signal that this consumer is ready.

pub fn has_coordination_support(&self) -> bool

Return whether this consumer has a readiness cursor attached.

pub fn try_consume_next(&mut self) -> Option<(Sequence, E)>

Try to consume the next available event.

pub fn try_consume_next_leased(&mut self) -> Option<MmapConsumerLease<'_, E>>

Try to lease the next available event without copying it out of the ring slot.

pub fn process_available<F>(&mut self, processor: F) -> usize
where F: FnMut(&E, Sequence),

Process all currently available events.

pub fn consume_next(&mut self) -> (Sequence, E)

Block until one event is available, then consume it.

pub fn consume_next_with_sleep(&mut self) -> (Sequence, E)

Block until one event is available, then consume it with the configured sleep policy.

pub fn consume_next_leased(&mut self) -> MmapConsumerLease<'_, E>

Block until one event is available, then lease it.

pub fn consume_next_leased_with_sleep(&mut self) -> MmapConsumerLease<'_, E>

Block until one event is available, then lease it with the configured sleep policy.

pub fn current_sequence(&self) -> Sequence

Return the last processed sequence.

pub fn consumer_id(&self) -> &str

Return the logical consumer id.