pub struct MmapCursorConfig {
pub path: PathBuf,
pub create: bool,
}Expand description
Configuration for file-backed mmap cursor segments.
Fields
path: PathBufPath to the backing file used for the shared mapping.
create: boolWhether to create the backing file or attach to an existing one.