pub struct AutoConsumer { /* private fields */ }Expand description
Automatic consumer that runs in a background thread.
This provides a handle to a consumer running automatic event processing in a separate thread. It supports graceful shutdown and cleanup operations.
Implementations
Sourceimpl AutoConsumer
impl AutoConsumer
Sourcepub fn shutdown_and_join(&mut self)
pub fn shutdown_and_join(&mut self)
Shutdown and wait for the consumer thread to finish
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Check if the consumer thread is still running